@@ -2,7 +2,7 @@ package Bundle::dualLived;
 
 use strict;
 
-$Bundle::dualLived::VERSION = '1.01';
+$Bundle::dualLived::VERSION = '1.03';
 
 1;
 
@@ -64,6 +64,8 @@ CPAN
 
 CPAN::Meta
 
+CPAN::Meta::Requirements
+
 CPAN::Meta::YAML
 
 CPANPLUS
@@ -126,8 +128,6 @@ Getopt::Long
 
 HTTP::Tiny
 
-I18N::LangTags
-
 IO
 
 IO::Compress::Base
@@ -176,8 +176,6 @@ Module::Metadata
 
 Module::Pluggable
 
-NEXT
-
 Net::Cmd
 
 Package::Constants
@@ -210,6 +208,8 @@ SelfLoader
 
 Shell
 
+Socket
+
 Storable
 
 Sys::Syslog
@@ -250,8 +250,6 @@ Unicode::Collate
 
 Unicode::Normalize
 
-Version::Requirements
-
 Win32
 
 Win32API::File
@@ -260,11 +258,11 @@ XSLoader
 
 =head1 AUTHOR
 
-Version 1.00 Kevin W. Henwood, <Khen1950fx@aol.com>
+Version 1.03 Kevin W. Henwood, <Khen1950fx@aol.com>
 
 head1 COPYRIGHT AND LICENSE
 
-Copyright (C) 2010, 2011 by Kevin W. Henwood
+Copyright (C) 2010-2013 by Kevin W. Henwood
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.8 or,
